=== modified file 'docker/build/Makefile.am'
--- docker/build/Makefile.am	2020-07-28 22:59:59 +0000
+++ docker/build/Makefile.am	2020-08-02 13:25:04 +0000
@@ -43,7 +43,7 @@
 	touch $@
 
 # minimal expected build to be packable
-CI_pack.tag: gits_artifacts.tag source.tag CI_base.tag free.tag upload/PATCHNOTES.md upload/CHANGELOG.md
+CI_pack.tag: gits_artifacts.tag source.tag CI_base.tag free.tag upload/PATCHNOTES.md upload/CHANGELOG.md upload/RELEASENOTES.md
 	touch $@
 
 # all windows builds
@@ -51,7 +51,7 @@
 	touch $@
 
 # all free linux builds (so, no steam)
-CI_free.tag: CI_base.tag free.tag
+CI_free.tag: CI_base.tag free.tag reformat.tag
 	touch $@
 
 # (OBSOLETE) targets for CI merge tests, a bit leaner than a full build
@@ -180,6 +180,9 @@
 upload/CHANGELOG.md: sourcetar.tag upload/.tag
 	${top_srcdir}/batch/make/patchnotes.py ${top_srcdir} ${top_srcdir}/CHANGELOG_FROZEN.md armagetronad armagetronad > $@
 
+upload/RELEASENOTES.md: ${src_dir}../deploy/RELEASENOTES.md upload/.tag
+	cp $< $@
+
 #***************************************************************
 
 # generic context with source
@@ -512,11 +515,28 @@
 .PRECIOUS:  context.build_client_steam result.build_client_steam context.appdir_client_steam result.build_server_steam context.build_server_steam context.appdir_server_steam context.winbuild_steam context.winsource_steam
 
 #***************************************************************
+# Reformat .md files
+
+context.reformat: rootcontext.64 CI_pack.tag ${srcdir}/context/reformat.sh
+	${srcdir}/prepare_context.sh $@.dir $<.dir/'*' upload/*.md ${srcdir}/context/reformat.sh
+	rm -f $@.dir/image
+	echo "armadeploy_64" > $@.dir/image
+	echo > $@
+result.reformat: context.reformat
+	+$(srcdir)/context_to_result.sh $@.dir ./reformat.sh $*
+	echo > $@
+
+reformat.tag: result.reformat
+	cp -a $<.dir/*.txt upload/
+	cp -a $<.dir/*.html upload/
+	echo > $@
+
+#***************************************************************
 
 # for testing, we want minimal builds before any deployment
 # in production, the CI solution is responsible for having built
 # everything not explicitly required here
-deploy_base.tag: CI_pack.tag debtest.tag ../deploy/targets.sh
+deploy_base.tag: CI_pack.tag debtest.tag reformat.tag ../deploy/targets.sh
 	echo > $@
 deploy_base: deploy_base.tag
 

=== added file 'docker/build/context/reformat.sh'
--- docker/build/context/reformat.sh	1970-01-01 00:00:00 +0000
+++ docker/build/context/reformat.sh	2020-08-02 13:25:04 +0000
@@ -0,0 +1,9 @@
+#!/bin/bash
+
+# takes *.md, reformats as .txt and .html
+
+for f in *.md; do
+    base=`echo $f | sed -e s,\.md\$,,` || exit $?
+    pandoc -f markdown -t plain < $f > ${base}.txt || exit $?
+    pandoc -f markdown -t html < $f > ${base}.html || exit $?
+done

=== added file 'docker/deploy/RELEASENOTES.md'
--- docker/deploy/RELEASENOTES.md	1970-01-01 00:00:00 +0000
+++ docker/deploy/RELEASENOTES.md	2020-08-02 13:25:04 +0000
@@ -0,0 +1,5 @@
+This is from the 0.2.8.3 branch of development. 
+It is the most recent LTS (Long Term Support) branch.
+While it is the most recent LTS branch, 
+it will receive security fixes, adaptions to new
+compilers and Linux versions and some less important bugfixes.

=== modified file 'docker/deploy/deploy_download.sh'
--- docker/deploy/deploy_download.sh	2020-07-28 22:59:59 +0000
+++ docker/deploy/deploy_download.sh	2020-08-02 13:25:04 +0000
@@ -108,12 +108,20 @@
 
 EOF
 
+if test -r ../upload/RELEASENOTES.md; then
+	cat >> ${POST} <<EOF
+### Release Notes
+
+EOF
+	cat ../upload/RELEASENOTES.md >> ${POST}
+	echo >> ${POST}
+fi
+
 if test -r ../upload/PATCHNOTES.md; then
 	cat >> ${POST} <<EOF
 ### Patch Notes
 
 EOF
-
 	cat ../upload/PATCHNOTES.md >> ${POST}
 fi
 

=== modified file 'docker/deploy/deploy_lp.sh'
--- docker/deploy/deploy_lp.sh	2020-07-09 19:39:31 +0000
+++ docker/deploy/deploy_lp.sh	2020-08-02 13:25:04 +0000
@@ -23,19 +23,23 @@
 . ./version.sh || exit $?
 . ./targets.sh || exit $?
 
+mv upload/RELEASENOTES.txt . || exit $?
+mv upload/PATCHNOTES.txt . || exit $?
+rm -f upload/*.md upload/*.html 
+
 if test ${STAGING} == true; then
     echo "Just staging, no upload to Launchpad"
 else
     EXIT=0
-    for f in upload/*${PACKAGE_VERSION}* upload/*.md; do
+    for f in upload/*${PACKAGE_VERSION}* upload/*.txt; do
 	if test -r $f; then
-	    if ! ./lp-project-upload ${LP_PROJECT} ${LP_SERIES} ${LP_VERSION} $f; then
+	    if ! ./lp-project-upload ${LP_PROJECT} ${LP_SERIES} ${LP_VERSION} $f PATCHNOTES.txt RELEASENOTES.txt; then
             sleep 10
-            if ! ./lp-project-upload ${LP_PROJECT} ${LP_SERIES} ${LP_VERSION} $f; then
+            if ! ./lp-project-upload ${LP_PROJECT} ${LP_SERIES} ${LP_VERSION} $f PATCHNOTES.txt RELEASENOTES.txt; then
                 sleep 10
-                if ! ./lp-project-upload ${LP_PROJECT} ${LP_SERIES} ${LP_VERSION} $f; then
+                if ! ./lp-project-upload ${LP_PROJECT} ${LP_SERIES} ${LP_VERSION} $f PATCHNOTES.txt RELEASENOTES.txt; then
                     sleep 10
-                    ./lp-project-upload ${LP_PROJECT} ${LP_SERIES} ${LP_VERSION} $f || EXIT=$?
+                    ./lp-project-upload ${LP_PROJECT} ${LP_SERIES} ${LP_VERSION} $f  PATCHNOTES.txt RELEASENOTES.txt || EXIT=$?
                 fi
             fi
         fi

=== modified file 'docker/deploy/lp-project-upload'
--- docker/deploy/lp-project-upload	2020-07-28 22:59:59 +0000
+++ docker/deploy/lp-project-upload	2020-08-02 13:25:04 +0000
@@ -132,36 +132,32 @@
 
         if extension == ".tbz":
             mime_type="application/bzip2"
-            if "_client_32_" in fn:
+            if "_32_" in fn:
                 description="Client Linux 32 Bit Tarball for Zero Install"
-            elif "_server_32_" in fn:
-                description="Server Linux 32 Bit Tarball for Zero Install"
-            elif "_client_64_" in fn:
+            elif "_64_" in fn:
                 description="Client Linux 64 Bit Tarball for Zero Install"
-            elif "_server_64_" in fn:
-                description="Server Linux 64 Bit Tarball for Zero Install"
             else:
                 file_type="Code Release Tarball"
                 description="Source"
         else:
-            if fn == "PATCHNOTES.md":
+            if fn == "CHANGELOG.txt":
                 file_type="Release Notes"
                 description="Patch Notes"
             if fn == "CHANGELOG.md":
                 file_type="ChangeLog File"
                 description="Changelog"
             if extension == ".AppImage":
-                description="AppImage for Linux"
+                description="Client AppImage for Linux"
                 Linux=True
             if extension == ".deb":
-                description="Debian Package"
+                description="Client Debian Package"
                 Linux=True
             if extension == ".dmg":
-                description="OSX Disk Image"
+                description="Client OSX Disk Image"
                 mime_type="application/x-apple-diskimage"
                 Mac=True
             if extension == ".exe":
-                description="Windows Installer"
+                description="Client Windows Installer"
                 mime_type="application/exe"
                 Windows=True
             if extension == ".zip":
@@ -178,12 +174,7 @@
                 else:
                     description = description.replace("Linux", "64 bit Linux")
             if "edicated" in filename or "server" in filename:
-                description="Server " + description
-            else:
-                if "common" in filename and extension == ".deb":
-                    description="Common " + description
-                else:
-                    description="Client " + description
+                description=description.replace("Client ", "Server ")
 
         print (filename,description,mime_type,file_type)
 
@@ -243,7 +234,7 @@
                     series.newMilestone(name=new_milestone)
 
     except HTTPError, error:
-        print 'An error happened in the upload:', error.content
+        print('An error happened in the upload:', error.content, error)
         sys.exit(1)
 
 if __name__ == '__main__':

=== modified file 'docker/images/armabuild/Dockerfile.proto'
--- docker/images/armabuild/Dockerfile.proto	2020-07-06 22:00:28 +0000
+++ docker/images/armabuild/Dockerfile.proto	2020-08-02 13:25:04 +0000
@@ -138,6 +138,7 @@
 FROM armabuild_base as armadeploy_base
 RUN apt-get -y update && apt-get install \
 0install-core \
+pandoc \
 -y
 
 FROM armadeploy_base as armadeploy

=== added file 'docker/images/copy_epoch.sh'
--- docker/images/copy_epoch.sh	1970-01-01 00:00:00 +0000
+++ docker/images/copy_epoch.sh	2020-08-02 13:25:04 +0000
@@ -0,0 +1,29 @@
+#!/bin/bash
+
+# usage: copy_epoch.sh <source> <target>
+# re-tag epoch <soure> to <target>
+
+set -x
+
+source=$1
+target=$2
+
+test -z "${source}" && exit 1
+test -z "${target}" && exit 1
+
+wd="`dirname $0`"
+. ${wd}/epoch.sh || exit $?
+
+for image in \
+    armawineblocks \
+    armasteam_64 \
+    armabuild_32 \
+    armadeb_64 \
+    armabuild_64 \
+    armalpine_32 \
+    armaroot_64 \
+    armadeploy_64 \
+    steamcmd \
+    ; do
+    docker tag ${REGISTRY}${image}:${source} ${REGISTRY}${image}:${target}
+done

